@@ -6,7 +6,7 @@ returns the minimum value, maximum value, add value, and
 initial value
 """
 
-import stl_path
+from snappi_trex import stl_path
 from trex.stl.api import *
 
 
